API deprecations
````````````````

The following API elements are deprecated:

- ``backend_gtk3cairo.FigureCanvasGTK3Cairo``,
- ``backend_wx.debug_on_error``, ``backend_wx.fake_stderr``,
  ``backend_wx.raise_msg_to_str``, ``backend_wx.MenuButtonWx``,
  ``backend_wx.PrintoutWx``,
